@@ -1,13 +1,13 @@
 from email.mime.image import MIMEImage
 from email.utils import unquote
-import os
+from pathlib import Path
 
 from django.core.mail import EmailMessage, EmailMultiAlternatives, make_msgid
 
 from .utils import UNSET
 
 
-class AnymailMessageMixin(object):
+class AnymailMessageMixin(EmailMessage):
     """Mixin for EmailMessage that exposes Anymail features.
 
     Use of this mixin is optional. You can always just set Anymail
@@ -32,8 +32,7 @@ class AnymailMessageMixin(object):
         self.merge_metadata = kwargs.pop('merge_metadata', UNSET)
         self.anymail_status = AnymailStatus()
 
-        # noinspection PyArgumentList
-        super(AnymailMessageMixin, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def attach_inline_image_file(self, path, subtype=None, idstring="img", domain=None):
         """Add inline image from file path to an EmailMessage, and return its content id"""
@@ -52,9 +51,9 @@ class AnymailMessage(AnymailMessageMixin, EmailMultiAlternatives):
 
 def attach_inline_image_file(message, path, subtype=None, idstring="img", domain=None):
     """Add inline image from file path to an EmailMessage, and return its content id"""
-    filename = os.path.basename(path)
-    with open(path, 'rb') as f:
-        content = f.read()
+    pathobj = Path(path)
+    filename = pathobj.name
+    content = pathobj.read_bytes()
     return attach_inline_image(message, content, filename, subtype, idstring, domain)
 
 
@@ -82,15 +81,19 @@ ANYMAIL_STATUSES = [
 ]
 
 
-class AnymailRecipientStatus(object):
+class AnymailRecipientStatus:
     """Information about an EmailMessage's send status for a single recipient"""
 
     def __init__(self, message_id, status):
         self.message_id = message_id  # ESP message id
         self.status = status  # one of ANYMAIL_STATUSES, or None for not yet sent to ESP
 
+    def __repr__(self):
+        return "AnymailRecipientStatus({message_id!r}, {status!r})".format(
+            message_id=self.message_id, status=self.status)
 
-class AnymailStatus(object):
+
+class AnymailStatus:
     """Information about an EmailMessage's send status for all recipients"""
 
     def __init__(self):
@@ -99,6 +102,21 @@ class AnymailStatus(object):
         self.recipients = {}  # per-recipient: { email: AnymailRecipientStatus, ... }
         self.esp_response = None
 
+    def __repr__(self):
+        def _repr(o):
+            if isinstance(o, set):
+                # force sorted order, for reproducible testing
+                item_reprs = [repr(item) for item in sorted(o)]
+                return "{%s}" % ", ".join(item_reprs)
+            else:
+                return repr(o)
+        details = ["status={status}".format(status=_repr(self.status))]
+        if self.message_id:
+            details.append("message_id={message_id}".format(message_id=_repr(self.message_id)))
+        if self.recipients:
+            details.append("{num_recipients} recipients".format(num_recipients=len(self.recipients)))
+        return "AnymailStatus<{details}>".format(details=", ".join(details))
+
     def set_recipient_status(self, recipients):
         self.recipients.update(recipients)
         recipient_statuses = self.recipients.values()
